#
# spec file for package python-jupyter_jupyterlab
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
Name:           python-jupyter_jupyterlab
Version:        0.33.4
Release:        2.9
Summary:        The JupyterLab notebook server extension
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyterlab/jupyterlab
Source:         https://files.pythonhosted.org/packages/py2.py3/j/jupyterlab/jupyterlab-%{version}-py2.py3-none-any.whl
Source99:       python-jupyter_jupyterlab-rpmlintrc
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module jupyter_jupyterlab_launcher >= 0.11.2}
BuildRequires:  %{python_module jupyter_notebook >= 5.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  npm >= 5
BuildRequires:  python-futures
BuildRequires:  python-rpm-macros
BuildRequires:  python-subprocess32
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  python-mock
%endif
Requires:       npm >= 5
Requires:       python-ipython_genutils
Requires:       python-jupyter_jupyterlab_launcher >= 0.11.2
Requires:       python-jupyter_notebook >= 5.3
Recommends:     python-Sphinx
Recommends:     python-recommonmark
Recommends:     python-sphinx_rtd_theme
Recommends:     python-requests
%ifpython2
Requires:       python-futures
Requires:       python-subprocess32
Requires:       python3-jupyter_jupyterlab
%endif
BuildArch:      noarch

%python_subpackages

%description
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is a user interface for Project Jupyter.
It offers familiar building blocks of the classic Jupyter
Notebook like notebook, terminal, text editor, file browser, rich outputs,
etc. in a flexible user inteface that can be extended
through third party extensions.

JupyterLab is currently in beta.

%prep
%setup -c -T

%build
# not needed

%install
%python_expand pip%{$python_bin_suffix} install --root=%{buildroot} %{SOURCE0}

if [ "$(dirname %{_prefix}/etc/jupyter)" != "$(dirname %{_sysconfdir}/jupyter)" ]; then
mkdir -p %{buildroot}%{_sysconfdir}
mv %{buildroot}%{_prefix}/etc/jupyter %{buildroot}%{_sysconfdir}/jupyter
rm -d %{buildroot}%{_prefix}/etc
fi

mkdir -p %{buildroot}%{_datadir}/jupyter/lab/extensions/
mkdir -p %{buildroot}%{_datadir}/jupyter/labextensions/

%python_expand sed -i -e '/^#!\//, 1d' %{buildroot}%{$python_sitelib}/jupyterlab/node-version-check.js
%python_expand sed -i -e '/^#!\//, 1d' %{buildroot}%{$python_sitelib}/jupyterlab/staging/yarn.js

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{fdupes %{buildroot}%{_datadir}/jupyter/ %{buildroot}%{python3_sitelib}}

%if %{with test}
%check
rm -r build
rm -r _build.*
%python_expand py.test-%{$python_bin_suffix}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%python3_only %{_bindir}/jlpm
%python3_only %{_bindir}/jupyter-lab
%python3_only %{_bindir}/jupyter-labextension
%python3_only %{_bindir}/jupyter-labhub
%python3_only %{_datadir}/jupyter/lab/
%python3_only %{_datadir}/jupyter/lab/extensions/
%python3_only %{_datadir}/jupyter/labextensions/
%python3_only %config %{_sysconfdir}/jupyter/jupyter_notebook_config.d/jupyterlab.json
%{python_sitelib}/jupyterlab
%{python_sitelib}/jupyterlab-%{version}.dist-info

%changelog
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.33.4
  + Key Features:
  * No longer in beta
  * Workspaces
  * Menu items
  * Keyboard shortcuts
  * Command palette items
  * Settings
  * Larger file uploads
  * Extension management and installation
  * Interface changes
  * Renderers
  * Changes for developers
  * Other fixes
* Wed May  2 2018 jengelh@inai.de
- Trim filler wording from description.
- Replace bashisms in %%install.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.32.0
  * Better handling of a corrupted or invalid state database ([#3619](https://github.com/jupyterlab/jupyterlab/issues/3619), [#3622](https://github.com/jupyterlab/jupyterlab/issues/3622), [#3687](https://github.com/jupyterlab/jupyterlab/issues/3687), [#4114](https://github.com/jupyterlab/jupyterlab/issues/4114)).
  * Fixing file dirty status indicator ([#3652](https://github.com/jupyterlab/jupyterlab/issues/3652)).
  * New option for whether to autosave documents ([#3734](https://github.com/jupyterlab/jupyterlab/issues/3734)).
  * More commands in the notebook context menu ([#3770](https://github.com/jupyterlab/jupyterlab/issues/3770), [#3909](https://github.com/jupyterlab/jupyterlab/issues/3909))
  * Defensively checking for completion metadata from kernels ([#3888](https://github.com/jupyterlab/jupyterlab/issues/3888))
  * New "Shutdown all" button  in the Running panel ([#3764](https://github.com/jupyterlab/jupyterlab/issues/3764))
  * Performance improvements wherein non-focused documents poll the server less ([#3931](https://github.com/jupyterlab/jupyterlab/issues/3931))
  * Changing the keyboard shortcut for singled-document-mode to something less easy to trigger ([#3889](https://github.com/jupyterlab/jupyterlab/issues/3889))
  * Performance improvements for rendering text streams, especially around progress bars ([#4045](https://github.com/jupyterlab/jupyterlab/issues/4045)).
  * Canceling a "Restart Kernel" now functions correctly ([#3703](https://github.com/jupyterlab/jupyterlab/issues/3703)).
  * Defer loading file contents until after the application has been restored ([#4087](https://github.com/jupyterlab/jupyterlab/issues/4087)).
  * Ability to rotate, flip, and invert images in the image viewer ([#4000](https://github.com/jupyterlab/jupyterlab/issues/4000))
  * Major performance improvements for large CSV viewing ([#3997](https://github.com/jupyterlab/jupyterlab/issues/3997)).
  * Always show the context menu in the file browser, even for an empty directory ([#4264](https://github.com/jupyterlab/jupyterlab/issues/4264)).
  * Handle asynchronous comm messages in the services library more correctly (Note: this means `@jupyterlab/services` is now at version 2.0!) ([[#4115](https://github.com/jupyterlab/jupyterlab/issues/4115)](https://github.com/jupyterlab/jupyterlab/pull/4115)).
  * Display the kernel banner in the console when a kernel is restarted to mark the restart ([[#3663](https://github.com/jupyterlab/jupyterlab/issues/3663)](https://github.com/jupyterlab/jupyterlab/pull/3663)).
  * Many tweaks to the UI, as well as better error handling.
* Mon Mar 12 2018 toddrme2178@gmail.com
- Bugfixes.
- Update summary and description
- Package other version of extensions directory.
* Wed Feb 28 2018 toddrme2178@gmail.com
- Package extensions directory.
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
